@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 15:00:05
-@LastEditTime: 2021-08-25 14:23:37
+@LastEditTime: 2021-09-02 20:23:02
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -104,8 +104,8 @@ class SyncPayOrderHandler(TaoBaseHandler):
             stat_base_model = StatBaseModel(context=self)
             key_list_dict = {}
             key_list_dict["PayUserCount"] = 1
-            key_list_dict["PayCount"] = invoke_result_data["pay_num"]
-            key_list_dict["PayMoneyCount"] = invoke_result_data["pay_price"]
+            key_list_dict["PayCount"] = invoke_result_data.data["pay_num"]
+            key_list_dict["PayMoneyCount"] = invoke_result_data.data["pay_price"]
             stat_base_model.add_stat_list(app_id, act_id, module_id, user_id, open_id, key_list_dict)
         return invoke_result_data
 
