@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-17 11:19:05
-@LastEditTime: 2021-08-23 09:31:50
+@LastEditTime: 2021-09-02 11:10:38
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -152,7 +152,7 @@ class FreeGiftHandler(TaoBaseHandler):
         invoke_result_data = self.business_process_executing(app_id, act_id, user_id, module_id, login_token)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        invoke_result_data = task_base_model.process_free_gift(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, invoke_result_data.data["check_new_user"], invoke_result_data.data["check_user_nick"], invoke_result_data.data["continue_request_expire"], invoke_result_data.data["task_sub_table"], invoke_result_data.data["asset_sub_table"])
+        invoke_result_data = task_base_model.process_free_gift(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, invoke_result_data.data["check_new_user"], invoke_result_data.data["check_user_nick"], invoke_result_data.data["continue_request_expire"])
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         invoke_result_data = self.business_process_executed(invoke_result_data)
@@ -172,7 +172,7 @@ class FreeGiftHandler(TaoBaseHandler):
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-        invoke_result_data.data = {"check_new_user":True,"check_user_nick":True,"continue_request_expire":5,"task_sub_table":None,"asset_sub_table":None}
+        invoke_result_data.data = {"check_new_user":True,"check_user_nick":True,"continue_request_expire":5}
         return invoke_result_data
 
     def business_process_executed(self, invoke_result_data):
@@ -211,7 +211,7 @@ class OneSignHandler(TaoBaseHandler):
         invoke_result_data = self.business_process_executing(app_id, act_id, user_id, module_id, login_token)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        invoke_result_data = task_base_model.process_one_sign(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, invoke_result_data.data["check_new_user"], invoke_result_data.data["check_user_nick"], invoke_result_data.data["continue_request_expire"], invoke_result_data.data["task_sub_table"], invoke_result_data.data["asset_sub_table"])
+        invoke_result_data = task_base_model.process_one_sign(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, invoke_result_data.data["check_new_user"], invoke_result_data.data["check_user_nick"], invoke_result_data.data["continue_request_expire"])
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         invoke_result_data = self.business_process_executed(invoke_result_data)
@@ -231,7 +231,7 @@ class OneSignHandler(TaoBaseHandler):
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-        invoke_result_data.data = {"check_new_user": True, "check_user_nick": True, "continue_request_expire": 5, "task_sub_table": None, "asset_sub_table": None}
+        invoke_result_data.data = {"check_new_user": True, "check_user_nick": True, "continue_request_expire": 5}
         return invoke_result_data
 
     def business_process_executed(self, invoke_result_data):
@@ -270,7 +270,7 @@ class WeeklySignHandler(TaoBaseHandler):
         invoke_result_data = self.business_process_executing(app_id, act_id, user_id, module_id, login_token)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        invoke_result_data = task_base_model.process_weekly_sign(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, invoke_result_data.data["check_new_user"], invoke_result_data.data["check_user_nick"], invoke_result_data.data["continue_request_expire"], invoke_result_data.data["task_sub_table"], invoke_result_data.data["asset_sub_table"])
+        invoke_result_data = task_base_model.process_weekly_sign(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, invoke_result_data.data["check_new_user"], invoke_result_data.data["check_user_nick"], invoke_result_data.data["continue_request_expire"])
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         invoke_result_data = self.business_process_executed(invoke_result_data)
@@ -290,7 +290,7 @@ class WeeklySignHandler(TaoBaseHandler):
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-        invoke_result_data.data = {"check_new_user": False, "check_user_nick": True, "continue_request_expire": 5, "task_sub_table": None, "asset_sub_table": None}
+        invoke_result_data.data = {"check_new_user": False, "check_user_nick": True, "continue_request_expire": 5}
         return invoke_result_data
 
     def business_process_executed(self, invoke_result_data):
@@ -331,7 +331,7 @@ class InviteNewUserHandler(TaoBaseHandler):
         invoke_result_data = self.business_process_executing(app_id, act_id, user_id, module_id, login_token)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        invoke_result_data = task_base_model.process_invite_new_user(app_id, act_id, module_id, user_id, login_token, invite_user_id, self.__class__.__name__, invoke_result_data.data["check_user_nick"], invoke_result_data.data["continue_request_expire"], invoke_result_data.data["task_sub_table"], invoke_result_data.data["invite_sub_table"])
+        invoke_result_data = task_base_model.process_invite_new_user(app_id, act_id, module_id, user_id, login_token, invite_user_id, self.__class__.__name__, invoke_result_data.data["check_user_nick"], invoke_result_data.data["continue_request_expire"])
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         invoke_result_data = self.business_process_executed(invoke_result_data)
@@ -351,7 +351,7 @@ class InviteNewUserHandler(TaoBaseHandler):
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-        invoke_result_data.data = {"check_user_nick": True, "continue_request_expire": 5, "task_sub_table": None, "invite_sub_table": None}
+        invoke_result_data.data = {"check_user_nick": True, "continue_request_expire": 5}
         return invoke_result_data
 
     def business_process_executed(self, invoke_result_data):
@@ -392,7 +392,7 @@ class InviteJoinMemberHandler(TaoBaseHandler):
         invoke_result_data = self.business_process_executing(app_id, act_id, user_id, module_id, login_token)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        invoke_result_data = task_base_model.process_invite_join_member(app_id, act_id, module_id, user_id, login_token, invite_user_id, self.__class__.__name__, self.request_code, invoke_result_data.data["check_new_user"], invoke_result_data.data["check_user_nick"], invoke_result_data.data["continue_request_expire"], invoke_result_data.data["task_sub_table"], invoke_result_data.data["invite_sub_table"])
+        invoke_result_data = task_base_model.process_invite_join_member(app_id, act_id, module_id, user_id, login_token, invite_user_id, self.__class__.__name__, self.request_code, invoke_result_data.data["check_new_user"], invoke_result_data.data["check_user_nick"], invoke_result_data.data["continue_request_expire"])
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         invoke_result_data = self.business_process_executed(invoke_result_data)
@@ -412,7 +412,7 @@ class InviteJoinMemberHandler(TaoBaseHandler):
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-        invoke_result_data.data = {"check_new_user": True, "check_user_nick": True, "continue_request_expire": 5, "task_sub_table": None, "invite_sub_table": None}
+        invoke_result_data.data = {"check_new_user": True, "check_user_nick": True, "continue_request_expire": 5}
         return invoke_result_data
 
     def business_process_executed(self, invoke_result_data):
@@ -451,7 +451,7 @@ class ShareReportHandler(TaoBaseHandler):
         invoke_result_data = self.business_process_executing(app_id, act_id, user_id, module_id, login_token)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        invoke_result_data = task_base_model.process_share_report(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, invoke_result_data.data["check_user_nick"], invoke_result_data.data["continue_request_expire"])
+        invoke_result_data = task_base_model.process_share_report(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, invoke_result_data.data["check_user_nick"], invoke_result_data.data["continue_request_expire"])
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         invoke_result_data = self.business_process_executed(invoke_result_data)
@@ -512,7 +512,7 @@ class CollectGoodsHandler(TaoBaseHandler):
         invoke_result_data = self.business_process_executing(app_id, act_id, user_id, module_id, login_token)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        invoke_result_data = task_base_model.process_collect_goods(app_id, act_id, module_id, user_id, login_token, goods_id, self.__class__.__name__, invoke_result_data.data["check_user_nick"], invoke_result_data.data["continue_request_expire"], invoke_result_data.data["task_sub_table"], invoke_result_data.data["collect_sub_table"])
+        invoke_result_data = task_base_model.process_collect_goods(app_id, act_id, module_id, user_id, login_token, goods_id, self.__class__.__name__, invoke_result_data.data["check_user_nick"], invoke_result_data.data["continue_request_expire"])
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         invoke_result_data = self.business_process_executed(invoke_result_data)
@@ -532,7 +532,7 @@ class CollectGoodsHandler(TaoBaseHandler):
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-        invoke_result_data.data = {"check_user_nick": True, "continue_request_expire": 5,"task_sub_table":None, "collect_sub_table":None}
+        invoke_result_data.data = {"check_user_nick": True, "continue_request_expire": 5}
         return invoke_result_data
 
     def business_process_executed(self, invoke_result_data):
@@ -573,7 +573,7 @@ class BrowseGoodsHandler(TaoBaseHandler):
         invoke_result_data = self.business_process_executing(app_id, act_id, user_id, module_id, login_token)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        invoke_result_data = task_base_model.process_browse_goods(app_id, act_id, module_id, user_id, login_token, goods_id, self.__class__.__name__, invoke_result_data.data["check_user_nick"], invoke_result_data.data["continue_request_expire"], invoke_result_data.data["task_sub_table"], invoke_result_data.data["browse_sub_table"])
+        invoke_result_data = task_base_model.process_browse_goods(app_id, act_id, module_id, user_id, login_token, goods_id, self.__class__.__name__, invoke_result_data.data["daily_repeat_browse"], invoke_result_data.data["check_user_nick"], invoke_result_data.data["continue_request_expire"])
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         invoke_result_data = self.business_process_executed(invoke_result_data)
@@ -593,7 +593,7 @@ class BrowseGoodsHandler(TaoBaseHandler):
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-        invoke_result_data.data = {"check_user_nick": True, "continue_request_expire": 5, "task_sub_table": None, "browse_sub_table": None}
+        invoke_result_data.data = {"daily_repeat_browse":False,"check_user_nick": True, "continue_request_expire": 5}
         return invoke_result_data
 
     def business_process_executed(self, invoke_result_data):
@@ -632,7 +632,7 @@ class FavorStoreHandler(TaoBaseHandler):
         invoke_result_data = self.business_process_executing(app_id, act_id, user_id, module_id, login_token)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        invoke_result_data = task_base_model.process_favor_store(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, invoke_result_data.data["check_user_nick"], invoke_result_data.data["continue_request_expire"], invoke_result_data.data["asset_sub_table"])
+        invoke_result_data = task_base_model.process_favor_store(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, invoke_result_data.data["check_user_nick"], invoke_result_data.data["continue_request_expire"])
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         invoke_result_data = self.business_process_executed(invoke_result_data)
@@ -652,7 +652,7 @@ class FavorStoreHandler(TaoBaseHandler):
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-        invoke_result_data.data = {"check_user_nick": True, "continue_request_expire": 5, "asset_sub_table": None}
+        invoke_result_data.data = {"check_user_nick": True, "continue_request_expire": 5}
         return invoke_result_data
 
     def business_process_executed(self, invoke_result_data):
@@ -691,7 +691,7 @@ class JoinMemberHandler(TaoBaseHandler):
         invoke_result_data = self.business_process_executing(app_id, act_id, user_id, module_id, login_token)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        invoke_result_data = task_base_model.process_join_member(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, invoke_result_data.data["check_user_nick"], invoke_result_data.data["continue_request_expire"], invoke_result_data.data["asset_sub_table"])
+        invoke_result_data = task_base_model.process_join_member(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, invoke_result_data.data["check_user_nick"])
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         invoke_result_data = self.business_process_executed(invoke_result_data)
@@ -711,7 +711,7 @@ class JoinMemberHandler(TaoBaseHandler):
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-        invoke_result_data.data = {"check_user_nick": True, "continue_request_expire": 5, "asset_sub_table": None}
+        invoke_result_data.data = {"check_user_nick": True, "continue_request_expire": 5}
         return invoke_result_data
 
     def business_process_executed(self, invoke_result_data):
