@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 18:31:06
-@LastEditTime: 2021-08-25 18:20:39
+@LastEditTime: 2021-09-02 09:28:55
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -127,7 +127,7 @@ class CheckIsMemberHandler(TaoBaseHandler):
             return self.response_json_error("error", "未授权请联系客服授权")
         top_base_model = TopBaseModel(context=self)
         app_key,app_secret = self.get_app_key_secret()
-        return self.response_json_success(top_base_model.check_is_member(app_id, access_token, app_key, app_secret, is_log))
+        return self.response_json_success(top_base_model.check_is_member(access_token, app_key, app_secret, is_log))
 
 
 class ApplyBlackUnbindHandler(TaoBaseHandler):
