@@ -2,13 +2,14 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-12 20:11:48
-@LastEditTime: 2021-08-26 18:05:41
+@LastEditTime: 2021-08-31 16:28:44
 @LastEditors: HuangJianYi
 :description: 
 """
 import ast
 import random
 import decimal
+import hashlib
 from copy import deepcopy
 from asq.initiators import query
 from urllib.parse import parse_qs, urlparse
@@ -165,9 +166,9 @@ class FrameBaseHandler(BaseApiHandler):
         """
         return SevenHelper.create_order_id(ran)
 
-    def check_continue_request(self, handler_name, app_id, object_id, expire=500):
+    def check_continue_request(self, handler_name, app_id, object_id, expire=100):
         """
-        :description: 一个用户同一handler频繁请求校验
+        :description: 一个用户同一handler频繁请求校验，只对同用户同接口同请求参数进行限制
         :param handler_name: handler名称
         :param app_id: 应用标识
         :param object_id: object_id(user_id或open_id)
@@ -177,10 +178,40 @@ class FrameBaseHandler(BaseApiHandler):
         """
         result = False, ""
         if object_id and handler_name and app_id:
-            if SevenHelper.is_continue_request(f"continue_request:{handler_name}_{app_id}_{object_id}", expire) == True:
+            request_param_dict = {}
+            if self.request.method!="GET" and self.request.body:
+                request_param_dict = json.loads(self.request.body)
+            else:
+                request_param_dict = dict([(k, v[0]) for k, v in parse_qs(self.request.query,True).items()])
+            sign = self.get_signature_md5(request_param_dict)
+            if SevenHelper.is_continue_request(f"continue_request:{handler_name}_{app_id}_{object_id}_{sign}", expire) == True:
                 result = True, f"操作太频繁,请{expire}毫秒后再试"
         return result
 
+    def get_signature_md5(self,request_param_dict,sign_key=""):
+        """
+        :description: 参数按照加密规则进行MD5加密
+        :description: 签名规则 signature_md5= ((参数1=参数1值&参数2=参数2值&signature_stamp={signature_stamp}))+密钥)进行Md5加密，参数顺序按照字母表的顺序排列
+        :param request_param_dict: 请求参数字典
+        :param sign_key: 接口密钥
+        :return: 加密后的md5值，由于跟客户端传来的加密参数进行校验
+        """
+        request_sign_params = {}
+        for k, v in request_param_dict.items():
+            if k == "param_signature_md5":
+                continue
+            if k == "signature_md5":
+                continue
+            request_sign_params[k] = v.replace(" ", "_seven_").replace("(", "_seven1_").replace(")", "_seven2_")
+        request_params_sorted = sorted(request_sign_params.items(),key=lambda e: e[0],reverse=False)
+        request_message = "&".join(k + "=" + CodingHelper.url_encode(v) for k, v in request_params_sorted)
+        request_message = request_message.replace("_seven_", "%20").replace("_seven1_", "(").replace("_seven2_", ")").replace("%27", "'")
+        # MD5摘要
+        request_encrypt = hashlib.md5()
+        request_encrypt.update((request_message + str(sign_key)).encode("utf-8"))
+        check_request_signature_md5 = request_encrypt.hexdigest().lower()
+        return check_request_signature_md5
+
     def add_request_user(self, app_id, object_id):
         """
         :description: 每分钟流量UV计数,用于登录接口限制登录
@@ -520,7 +551,7 @@ def filter_check_head(is_check=True, no_check_params=None, sign_key=""):
                         if not device_dict.__contains__("signature_md5"):
                             return self.response_json_error("signature_md5", "缺少参数signature_md5")
                         # 验证头部签名是否成功
-                        client_head_dict = dict([(k, v[0]) for k, v in parse_qs(clientheaderinfo_string, True).items() if k != "SignatureMD5" and not k in no_check_array])
+                        client_head_dict = dict([(k, v[0]) for k, v in parse_qs(clientheaderinfo_string, True).items() if k != "signature_md5" and not k in no_check_array])
                         head_signature_md5 = self.get_signature_md5(client_head_dict, sign_key)
                         signature_md5 = device_dict["signature_md5"].lower()
                         if signature_md5 != head_signature_md5:
