@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-12 20:11:48
-@LastEditTime: 2021-08-26 10:28:43
+@LastEditTime: 2021-09-02 18:50:00
 @LastEditors: HuangJianYi
 :description: 
 """
@@ -19,10 +19,11 @@ class AssetBaseModel():
     """
     :description: 资产管理业务模型
     """
-    def __init__(self, context):
+    def __init__(self, context, logging_error=None):
         self.context = context
+        self.logging_link_error = logging_error
 
-    def _get_user_asset_id(self, act_id, user_id, asset_type, asset_object_id):
+    def _get_user_asset_id_md5(self, act_id, user_id, asset_type, asset_object_id):
         """
         :description: 生成用户资产唯一标识
         :param act_id：活动标识
@@ -36,18 +37,19 @@ class AssetBaseModel():
             return 0
         return CryptoHelper.md5_encrypt_int(f"{act_id}_{user_id}_{asset_type}_{asset_object_id}")
 
-    def _get_asset_check_code(self, id, asset_value, sign_key):
+    def _get_asset_check_code(self, id_md5, asset_value, sign_key):
         """
         :description: 生成用户资产校验码
         :param 用户资产唯一标识
+        :param id_md5：id_md5
         :param asset_value：当前资产值
         :param sign_key：签名key,目前使用app_id作为签名key
         :return: 用户资产校验码
         :last_editors: HuangJianYi
         """
-        if not id or not asset_value:
+        if not id_md5 or not asset_value:
             return ""
-        return CryptoHelper.md5_encrypt(f"{id}_{asset_value}", sign_key)
+        return CryptoHelper.md5_encrypt(f"{id_md5}_{asset_value}", sign_key)
 
     def _add_onlyid_warn_stat(self,handler_name):
         """
@@ -70,7 +72,7 @@ class AssetBaseModel():
             redis_init.hincrby(hash_name_2, {str(SevenHelper.get_now_int(fmt='%Y%m%d%H%M'))}, 1)
             redis_init.expire(hash_name_2, 24 * 3600)
             
-    def update_user_asset(self, app_id, act_id, module_id, user_id, open_id, user_nick, asset_type, asset_value, asset_object_id, source_type, source_object_id, source_object_name, log_title, only_id="",handler_name="",request_code="", info_json={}, sub_table=None):
+    def update_user_asset(self, app_id, act_id, module_id, user_id, open_id, user_nick, asset_type, asset_value, asset_object_id, source_type, source_object_id, source_object_name, log_title, only_id="",handler_name="",request_code="", info_json={}):
         """
         :description: 变更资产
         :param act_id：活动标识
@@ -89,7 +91,6 @@ class AssetBaseModel():
         :param handler_name:接口名称
         :param request_code:请求唯一标识，从seven_framework框架获取对应request_code
         :param info_json：资产流水详情，用于存放业务方自定义字典
-        :param sub_table：分表名称
         :return: 返回实体InvokeResultData
         :last_editors: HuangJianYi
         """
@@ -108,8 +109,8 @@ class AssetBaseModel():
             invoke_result_data.error_message = "资产类型为价格档位,参数asset_object_id不能为空或等于0"
             return invoke_result_data
 
-        user_asset_id = self._get_user_asset_id(act_id, user_id, asset_type, asset_object_id)
-        if user_asset_id == 0:
+        user_asset_id_md5 = self._get_user_asset_id_md5(act_id, user_id, asset_type, asset_object_id)
+        if user_asset_id_md5 == 0:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "修改失败"
@@ -126,14 +127,14 @@ class AssetBaseModel():
                 #添加唯一标识预警拦截计数,用于控制台跑数据进行并发预警
                 self._add_onlyid_warn_stat(handler_name)
                 return invoke_result_data
-
+        sub_table = SevenHelper.get_sub_table(act_id,config.get_value("asset_sub_table_count",0))
         db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
         user_asset_model = UserAssetModel(db_transaction=db_transaction, sub_table=sub_table, context=self.context)
         asset_log_model = AssetLogModel(db_transaction=db_transaction, sub_table=sub_table, context=self.context)
         asset_only_model = AssetOnlyModel(db_transaction=db_transaction, sub_table=sub_table, context=self.context)
         asset_inventory_model = AssetInventoryModel(db_transaction=db_transaction, sub_table=sub_table, context=self.context)
 
-        acquire_lock_name = f"userasset:{user_asset_id}"
+        acquire_lock_name = f"userasset:{user_asset_id_md5}"
         acquire_lock_status, identifier = SevenHelper.redis_acquire_lock(acquire_lock_name)
         if acquire_lock_status == False:
             invoke_result_data.success = False
@@ -147,7 +148,7 @@ class AssetBaseModel():
             old_user_asset_id = 0
             history_asset_value = 0
 
-            user_asset = user_asset_model.get_entity_by_id(user_asset_id)
+            user_asset = user_asset_model.get_entity("id_md5=%s",params=[user_asset_id_md5])
             if user_asset:
                 if user_asset.asset_value + asset_value < 0:
                     SevenHelper.redis_release_lock(acquire_lock_name, identifier)
@@ -156,11 +157,11 @@ class AssetBaseModel():
                     invoke_result_data.error_message = "变更后的资产不能为负数"
                     return invoke_result_data
 
-                old_user_asset_id = user_asset_id
+                old_user_asset_id = user_asset.id
                 history_asset_value = user_asset.asset_value
             else:
                 user_asset = UserAsset()
-                user_asset.id = user_asset_id
+                user_asset.id_md5 = user_asset_id_md5
                 user_asset.app_id = app_id
                 user_asset.act_id = act_id
                 user_asset.user_id = user_id
@@ -171,22 +172,22 @@ class AssetBaseModel():
                 user_asset.create_date = now_datetime
 
             user_asset.asset_value += asset_value
-            user_asset.asset_check_code = self._get_asset_check_code(user_asset_id, user_asset.asset_value, app_id)
+            user_asset.asset_check_code = self._get_asset_check_code(user_asset_id_md5, user_asset.asset_value, app_id)
             user_asset.modify_date = now_datetime
 
             old_asset_inventory_id = 0
-            asset_inventory_id = CryptoHelper.md5_encrypt_int(f"{act_id}_{user_id}_{asset_type}_{asset_object_id}_{now_day_int}")
-            asset_inventory = asset_inventory_model.get_entity_by_id(asset_inventory_id)
+            asset_inventory_id_md5 = CryptoHelper.md5_encrypt_int(f"{act_id}_{user_id}_{asset_type}_{asset_object_id}_{now_day_int}")
+            asset_inventory = asset_inventory_model.get_entity("id_md5=%s",params=[asset_inventory_id_md5])
             asset_inventory_update_sql = f"process_count=0,now_value={user_asset.asset_value}"
             if asset_inventory:
-                old_asset_inventory_id = asset_inventory_id
+                old_asset_inventory_id = asset_inventory.id
                 if asset_value > 0:
                     asset_inventory_update_sql += f",inc_value=inc_value+{asset_value}"
                 else:
                     asset_inventory_update_sql += f",dec_value=dec_value+{asset_value}"
             else:
                 asset_inventory = AssetInventory()
-                asset_inventory.id = asset_inventory_id
+                asset_inventory.id_md5 = asset_inventory_id_md5
                 asset_inventory.app_id = app_id
                 asset_inventory.act_id = act_id
                 asset_inventory.user_id = user_id
@@ -204,7 +205,6 @@ class AssetBaseModel():
                 asset_inventory.create_day = now_day_int
 
             asset_log = AssetLog()
-            asset_log.id = CryptoHelper.md5_encrypt_int(f"{act_id}_{user_id}_{UUIDHelper.get_uuid()}")
             asset_log.app_id = app_id
             asset_log.act_id = act_id
             asset_log.module_id = module_id
@@ -230,7 +230,7 @@ class AssetBaseModel():
 
             if only_id:
                 asset_only = AssetOnly()
-                asset_only.id = CryptoHelper.md5_encrypt_int(f"{act_id}_{user_id}_{only_id}")
+                asset_only.id_md5 = CryptoHelper.md5_encrypt_int(f"{act_id}_{user_id}_{only_id}")
                 asset_only.app_id = app_id
                 asset_only.act_id = act_id
                 asset_only.user_id = user_id
@@ -272,7 +272,10 @@ class AssetBaseModel():
 
         except Exception as ex:
             db_transaction.rollback_transaction()
-            self.context.logging_link_error("【变更资产】" + str(ex))
+            if self.context:
+                self.context.logging_link_error("【变更资产】" + str(ex))
+            elif self.logging_link_error:
+                self.logging_link_error("【变更资产】" + str(ex))
             invoke_result_data.success = False
             invoke_result_data.error_code = "exception"
             invoke_result_data.error_message = "系统繁忙,请稍后再试"
@@ -281,14 +284,13 @@ class AssetBaseModel():
 
         return invoke_result_data
 
-    def get_user_asset_list(self, app_id, act_id, user_ids, asset_type=0, sub_table=None):
+    def get_user_asset_list(self, app_id, act_id, user_ids, asset_type=0):
         """
         :description: 获取用户资产列表
         :param app_id：应用标识
         :param act_id：活动标识
         :param user_ids：用户标识 多个逗号,分隔
         :param asset_type：资产类型(1-次数2-积分3-价格档位)
-        :param sub_table：分表名称
         :return: 返回list
         :last_editors: HuangJianYi
         """
@@ -307,6 +309,7 @@ class AssetBaseModel():
             else:
                 condition += " AND user_id=%s"
                 params.append(user_ids)
+        sub_table = SevenHelper.get_sub_table(act_id,config.get_value("asset_sub_table_count",0))
         user_asset_model = UserAssetModel(sub_table=sub_table, context=self.context)
         user_asset_dict_list = user_asset_model.get_dict_list(condition, params=params)
         if len(user_asset_dict_list) > 0:
@@ -317,7 +320,7 @@ class AssetBaseModel():
                     user_asset_dict["asset_value"] = 0
         return user_asset_dict_list
 
-    def get_user_asset(self, app_id, act_id, user_id, asset_type, asset_object_id, sub_table=None):
+    def get_user_asset(self, app_id, act_id, user_id, asset_type, asset_object_id):
         """
         :description: 获取具体的用户资产
         :param app_id：应用标识
@@ -325,15 +328,15 @@ class AssetBaseModel():
         :param user_id：用户标识
         :param asset_type：资产类型(1-次数2-积分3-价格档位)
         :param asset_object_id：资产对象标识,没有传空
-        :param sub_table：分表名称
         :return: 返回list
         :last_editors: HuangJianYi
         """
         if not act_id or not user_id or not asset_type:
             return None
+        sub_table = SevenHelper.get_sub_table(act_id,config.get_value("asset_sub_table_count",0))
         user_asset_model = UserAssetModel(sub_table=sub_table, context=self.context)
-        user_asset_id = self._get_user_asset_id(act_id, user_id, asset_type, asset_object_id)
-        user_asset_dict = user_asset_model.get_dict_by_id(user_asset_id)
+        user_asset_id_md5 = self._get_user_asset_id_md5(act_id, user_id, asset_type, asset_object_id)
+        user_asset_dict = user_asset_model.get_dict("id_md5=%s",params=[user_asset_id_md5])
         if user_asset_dict:
             if user_asset_dict["app_id"] != str(app_id):
                 user_asset_dict["asset_value"] = 0
@@ -341,7 +344,7 @@ class AssetBaseModel():
                 user_asset_dict["asset_value"] = 0
         return user_asset_dict
 
-    def get_asset_log_list(self, app_id, act_id, asset_type, page_size=20, page_index=0, user_id=0, asset_object_id="", start_date="", end_date="", user_nick="", open_id="", source_type=0, source_object_id="", field="*", sub_table=None):
+    def get_asset_log_list(self, app_id, act_id, asset_type, page_size=20, page_index=0, user_id=0, asset_object_id="", start_date="", end_date="", user_nick="", open_id="", source_type=0, source_object_id="", field="*"):
         """
         :description: 获取用户资产流水记录
         :param app_id：应用标识
@@ -358,7 +361,6 @@ class AssetBaseModel():
         :param source_type：来源类型（1-购买2-任务3-手动配置4-抽奖5-回购）
         :param source_object_id：来源对象标识(比如来源类型是任务则对应任务类型)
         :param field：查询字段
-        :param sub_table：分表名称
         :return: 返回PageInfo
         :last_editors: HuangJianYi
         """
@@ -396,7 +398,7 @@ class AssetBaseModel():
         if source_object_id:
             condition += " AND source_object_id=%s"
             params.append(source_object_id)
-
+        sub_table = SevenHelper.get_sub_table(act_id,config.get_value("asset_sub_table_count",0))
         page_list, total = AssetLogModel(sub_table=sub_table, context=self.context).get_dict_page_list(field, page_index, page_size, condition, order_by="create_date desc", params=params)
         if len(page_list) > 0:
             for item in page_list:
