@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 09:44:36
-@LastEditTime: 2021-08-09 15:43:12
+@LastEditTime: 2021-08-26 11:00:44
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -15,7 +15,7 @@ from seven_cloudapp_frame.models.db_models.ip.ip_info_model import *
 
 class IpBaseModel():
     """
-    :description: IP信息基类
+    :description: IP信息业务模型
     """
     def __init__(self, context):
         self.context = context
