@@ -2,16 +2,18 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 09:24:43
-@LastEditTime: 2021-08-26 11:08:38
+@LastEditTime: 2021-09-02 14:07:35
 @LastEditors: HuangJianYi
 @Description: 
 """
+from seven_cloudapp_frame.models.user_base_model import UserBaseModel
 from seven_cloudapp_frame.models.frame_base_model import FrameBaseModel
 from seven_cloudapp_frame.libs.customize.seven_helper import *
 from seven_cloudapp_frame.models.seven_model import *
 from seven_cloudapp_frame.models.app_base_model import *
 from seven_cloudapp_frame.models.top_base_model import *
 from seven_cloudapp_frame.models.price_base_model import *
+from seven_cloudapp_frame.models.asset_base_model import *
 from seven_cloudapp_frame.models.db_models.act.act_module_model import *
 from seven_cloudapp_frame.models.db_models.prize.prize_order_model import *
 from seven_cloudapp_frame.models.db_models.prize.prize_order_model import *
@@ -629,8 +631,9 @@ class OrderBaseModel(FrameBaseModel):
                         else:
                             invoke_result_data.success = False
                             invoke_result_data.error_code = "error"
-                            invoke_result_data.error_message = "没有匹配订单"   
-                        black_status = self.check_pull_black(user_info_dict,act_info_dict["is_black"],act_info_dict["refund_count"],all_order_list)
+                            invoke_result_data.error_message = "没有匹配订单"
+                        user_base_model = UserBaseModel(context=self.context)
+                        black_status = user_base_model.check_pull_black(user_info_dict,act_info_dict["is_black"],act_info_dict["refund_count"],all_order_list)
                         if black_status == True:
                             invoke_result_data.data["user_state"] = 1
                     else:
