@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-08-12 09:06:24
-@LastEditTime: 2021-08-26 10:30:18
+@LastEditTime: 2021-09-01 16:12:50
 @LastEditors: HuangJianYi
 :description: 淘宝top接口基础类
 """
@@ -598,7 +598,6 @@ class TopBaseModel():
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-
         num_iid_list = num_iids.split(',')
         page_size = 20
         page_count = int(len(num_iid_list) / page_size) if len(num_iid_list) % page_size == 0 else int(len(num_iid_list) / page_size) + 1
@@ -628,6 +627,10 @@ class TopBaseModel():
                             invoke_result_data.error_code = "no_power"
                             invoke_result_data.error_message = content[len("submsg="):]
                             return invoke_result_data
+                        if "submsg=num_iid有误，必须大于0" in content:
+                            invoke_result_data.error_code = "param_error"
+                            invoke_result_data.error_message = content[len("submsg="):]
+                            return invoke_result_data
                         if "submsg=" in content:
                             invoke_result_data.error_code = "error"
                             invoke_result_data.error_message = content[len("submsg="):]
