@@ -2,9 +2,9 @@
 """
 :Author: HuangJianYi
 :Date: 2020-04-16 14:38:22
-@LastEditTime: 2021-08-19 19:08:50
+@LastEditTime: 2021-08-26 16:41:16
 @LastEditors: HuangJianYi
-:Description: 基础路由
+:Description: 基础路由   业务方可以直接使用语句 handlers.extend(seven_cloudapp_frame.route.seven_cloudapp_frame_route()) 引入
 """
 # 框架引用
 from seven_framework.web_tornado.monitor import MonitorHandler
@@ -16,7 +16,7 @@ def seven_cloudapp_frame_route():
     return [
         (r"/monitor", MonitorHandler),
         (r"/", IndexHandler),
-        #客户端
+        #淘宝客户端
         (r"/client/address_list", address.AddressInfoListHandler),  #收货地址列表
         (r"/client/login", user.LoginHandler),  #小程序登录
         (r"/client/update_user_info", user.UpdateUserInfoHandler),  #更新用户信息如昵称、头像等
@@ -24,10 +24,8 @@ def seven_cloudapp_frame_route():
         (r"/client/apply_black_unbind", user.ApplyBlackUnbindHandler),  #申请黑名单解封
         (r"/client/user_asset_list", user.UserAssetListHandler),  #用户资产列表
         (r"/client/asset_log_list", user.AssetLogListHandler),  #用户资产流水列表
-        (r"/client/prize_roster_list", user.PrizeRosterListHandler),  #中奖记录列表
         (r"/client/get_join_member_url", user.GetJoinMemberUrlHandler),  #加入会员地址
         (r"/client/get_coupon_prize", user.GetCouponPrizeHandler),  #领取淘宝优惠券
-        (r"/client/horseracelamp_list", user.HorseracelampListHandler),  #中奖记录跑马灯列表
         (r"/client/theme_info", theme.ThemeInfoHandler),  #主题信息
         (r"/client/save_theme", theme.SaveThemeHandler),  #保存主题信息，由前端通过工具进行保存
         (r"/client/save_skin", theme.SaveSkinHandler),  #保存皮肤信息，由前端通过工具进行保存
@@ -37,11 +35,13 @@ def seven_cloudapp_frame_route():
         (r"/client/act_info", act.ActInfoHandler),  #活动信息
         (r"/client/act_prize_list", act.ActPrizeListHandler),  #活动奖品列表
         (r"/client/app_expire", app.AppExpireHandler),  #小程序过期时间
-        (r"/client/submit_sku", goods.SubmitSkuHandler),  #中奖记录选择sku
         (r"/client/sku_info", goods.SkuInfoHandler),  #sku信息
         (r"/client/goods_list", goods.GoodsListHandler),  #商品列表
+        (r"/client/horseracelamp_list", order.HorseracelampListHandler),  #中奖记录跑马灯列表
         (r"/client/prize_order_list", order.PrizeOrderListHandler),  #用户订单列表
         (r"/client/create_prize_order", order.SelectPrizeOrderHandler),  #选择中奖记录进行下单
+        (r"/client/submit_sku", order.SubmitSkuHandler),  #中奖记录选择sku
+        (r"/client/prize_roster_list", order.PrizeRosterListHandler),  #中奖记录列表
         (r"/client/sync_pay_order", order.SyncPayOrderHandler),  #同步淘宝支付订单给用户加资产
         (r"/client/task_info_list", task.TaskInfoListHandler),  #任务列表
         (r"/client/receive_reward", task.ReceiveRewardHandler),  #统一领取任务奖励
